@@ -16,7 +16,7 @@ our @EXPORT_OK = qw(
     is_hash     every    noop        identity
 );
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use constant ARG_PLACE_HOLDER => {};
 
@@ -490,10 +490,10 @@ The iteratee is invoked with four arguments:
     }, {}, [1,2,3]);
 
     # {
-        key => 1,
-        key => 2,
-        key => 3,
-    }
+    #    key => 1,
+    #    key => 2,
+    #    key => 3,
+    # }
 =cut
 
 =head2 flatten
@@ -871,15 +871,15 @@ Iterates over elements of collection, returning only elements the predicate retu
     }, $people);
 
     # [
-        {
-            name => 'john',
-            age => 25,
-        },
-        {
-            name => 'Sally',
-            age => 25,
-        }
-    ]
+    #    {
+    #        name => 'john',
+    #        age => 25,
+    #    },
+    #    {
+    #        name => 'Sally',
+    #        age => 25,
+    #    }
+    # ]
 
 =cut
 
